@@ -15,6 +15,7 @@ require Vcf;
 
 extends 'BioX::Wrapper';
 with 'MooseX::Getopt';
+with 'MooseX::Getopt::Usage';
 
 =head1 NAME
 
@@ -26,20 +27,20 @@ Version 0.06
 
 =cut
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 
 =head1 SYNOPSIS
 
-    annovar-wrapper.pl --vcfs file1.vcf,file2.vcf --annovardb_path /path/to/annovar/dbs 
+    annovar-wrapper.pl --vcfs file1.vcf,file2.vcf --annovardb_path /path/to/annovar/dbs
 
 This module is a wrapper around the popular annotation tool, annovar. http://www.openbioinformatics.org/annovar/ . The commands generated are taken straight from the documentation. In addition, there is an option to reannotate using vcf-annotate from vcftools.
 
-It takes as its input a list or directory of vcf files, bgzipped and tabixed or not, and uses annovar to create annotation files. These multianno table files can be optionally reannotated into the vcf file. This script does not actually execute any commands, only writes them to STDOUT for the user to run as they wish. 
+It takes as its input a list or directory of vcf files, bgzipped and tabixed or not, and uses annovar to create annotation files. These multianno table files can be optionally reannotated into the vcf file. This script does not actually execute any commands, only writes them to STDOUT for the user to run as they wish.
 
-It comes with an executable script annovar-wrapper.pl. This should be sufficient for most of your needs, but if you wish to overwrite methods you can always do so in the usual Moose fashion. 
+It comes with an executable script annovar-wrapper.pl. This should be sufficient for most of your needs, but if you wish to overwrite methods you can always do so in the usual Moose fashion.
 
-    #!/usr/bin/env perl 
+    #!/usr/bin/env perl
 
     package Main;
 
@@ -64,8 +65,8 @@ It comes with an executable script annovar-wrapper.pl. This should be sufficient
         #things to add to variable declaration
     );
 
-    #or 
-    
+    #or
+
     has 'variable' => (
         #override variable declaration
     );
@@ -76,7 +77,7 @@ Please see the Moose::Manual::MethodModifiers for more information.
 
 =head1 Prerequisites
 
-This module requires the annovar download. The easiest thing to do is to put the annovar scripts in your ENV{PATH}, but if you choose not to do this you can also pass in the location with 
+This module requires the annovar download. The easiest thing to do is to put the annovar scripts in your ENV{PATH}, but if you choose not to do this you can also pass in the location with
 
 annovar-wrapper.pl --tableannovar_path /path/to/table_annovar.pl --convert2annovar_path /path/to/convert2annovar.pl
 
@@ -86,7 +87,7 @@ Vcftools is publicly available for download.  http://vcftools.sourceforge.net/.
 
     export PERL5LIB=$PERL5LIB:path_to_vcftools/perl
 
-If you wish to you reannotate the vcf file you need to have bgzip and tabix installed, and have the executables in vcftools in your path. 
+If you wish to you reannotate the vcf file you need to have bgzip and tabix installed, and have the executables in vcftools in your path.
 
     export PATH=$PATH:path_to_vcftools
 
@@ -122,7 +123,7 @@ You can put the location of the annovar scripts in your ENV{PATH}, and the defau
 
 =cut
 
-has 'tableannovar_path' => ( 
+has 'tableannovar_path' => (
     is => 'rw',
     isa => 'Str',
     required => 1,
@@ -135,7 +136,7 @@ You can put the location of the annovar scripts in your ENV{PATH}, and the defau
 
 =cut
 
-has 'convert2annovar_path' => ( 
+has 'convert2annovar_path' => (
     is => 'rw',
     isa => 'Str',
     required => 1,
@@ -184,7 +185,7 @@ has 'convert2annovar_opts' => (
 
 =head3 annovar_dbs
 
-These are pretty much all the databases listed on 
+These are pretty much all the databases listed on
 
 http://www.openbioinformatics.org/annovar/annovar_download.html for hg19 that I tested as working
 
@@ -202,11 +203,12 @@ http://www.openbioinformatics.org/annovar/annovar_download.html for hg19 that I
     --annovar_dbs cg46 --annovar_dbs cg69 --annovar_dbs nci60
 
 =cut
+
 #TODO
 #Add in a hashref so I don't have to remember the list
 #The following are redundant within other databases
 #esp are in popfreq_all
-#esp6500si_aa 
+#esp6500si_aa
 #esp6500si_ea
 #ljb23 are in ljb23_all
 #ljb23_fathmm
@@ -252,7 +254,7 @@ refGene
 
 =head3 annovar_fun
 
-Functions of the individual databases can be found at 
+Functions of the individual databases can be found at
 
 What function your DB may already be listed otherwise it is probably listed in the URLS under Annotation: Gene-Based, Region-Based, or Filter-Based
 
@@ -262,7 +264,7 @@ Functions must be given in the corresponding order of your annovar_dbs
 
     --annovar_fun f,f,g
 
-    #or 
+    #or
 
     --annovar_fun f --annovar_fun f --annovar_fun g
 
@@ -307,14 +309,14 @@ has 'annovar_cols' => (
         #Old table_annovar.pl script
 #        $href->{popfreq_max} = ["PopFreqMax"];
 #        $href->{popfreq_all} = ["PopFreqMax","1000G2012APR_ALL","1000G2012APR_AFR","1000G2012APR_AMR","1000G2012APR_ASN","1000G2012APR_EUR","ESP6500si_AA","ESP6500si_EA","CG46","NCI60","SNP137","COSMIC65","DISEASE"];
-#        $href->{refGene} = ["Func.refGene","Gene.refGene","ExonicFunc.refGene","AAChange.refGene"]; 
+#        $href->{refGene} = ["Func.refGene","Gene.refGene","ExonicFunc.refGene","AAChange.refGene"];
 #	    $href->{ljb_all} = [ qw/LJB_PhyloP LJB_PhyloP_Pred LJB_SIFT LJB_SIFT_Pred LJB_PolyPhen2 LJB_PolyPhen2_Pred LJB_LRT LJB_LRT_Pred LJB_MutationTaster LJB_MutationTaster_Pred LJB_GERP++/ ];
 #	    $href->{ljb2_all} = [ qw/LJB2_SIFT LJB2_PolyPhen2_HDIV LJB2_PP2_HDIV_Pred LJB2_PolyPhen2_HVAR LJB2_PolyPhen2_HVAR_Pred LJB2_LRT LJB2_LRT_Pred LJB2_MutationTaster LJB2_MutationTaster_Pred LJB_MutationAssessor LJB_MutationAssessor_Pred LJB2_FATHMM LJB2_GERP++ LJB2_PhyloP LJB2_SiPhy/ ];
 #	$href->{ljb23_all} = [ qw/LJB23_SIFT_score LJB23_SIFT_score_converted LJB23_SIFT_pred LJB23_Polyphen2_HDIV_score LJB23_Polyphen2_HDIV_pred LJB23_Polyphen2_HVAR_score LJB23_Polyphen2_HVAR_pred LJB23_LRT_score LJB23_LRT_score_converted LJB23_LRT_pred LJB23_MutationTaster_score LJB23_MutationTaster_score_converted LJB23_MutationTaster_pred LJB23_MutationAssessor_score LJB23_MutationAssessor_score_converted LJB23_MutationAssessor_pred LJB23_FATHMM_score LJB23_FATHMM_score_converted LJB23_FATHMM_pred LJB23_RadialSVM_score LJB23_RadialSVM_score_converted LJB23_RadialSVM_pred LJB23_LR_score LJB23_LR_pred LJB23_GERP++ LJB23_PhyloP LJB23_SiPhy/ ];
 
 #        #Which one?
-#        #$href->{refGene} = ["Func.refGene","Gene.refGene", "ExonicFunc.refGene","AAChange.refGene"]; 
-        $href->{refGene} = ["Func.refGene","Gene.refGene","GeneDetail.refGene", "ExonicFunc.refGene","AAChange.refGene"]; 
+#        #$href->{refGene} = ["Func.refGene","Gene.refGene", "ExonicFunc.refGene","AAChange.refGene"];
+        $href->{refGene} = ["Func.refGene","Gene.refGene","GeneDetail.refGene", "ExonicFunc.refGene","AAChange.refGene"];
         $href->{ljb_all} = [ qw/LJB_PhyloP LJB_PhyloP_Pred LJB_SIFT LJB_SIFT_Pred LJB_PolyPhen2 LJB_PolyPhen2_Pred LJB_LRT LJB_LRT_Pred LJB_MutationTaster LJB_MutationTaster_Pred LJB_GERPPP/ ];
         $href->{ljb2_all} = [ qw/LJB2_SIFT LJB2_PolyPhen2_HDIV LJB2_PP2_HDIV_Pred LJB2_PolyPhen2_HVAR LJB2_PolyPhen2_HVAR_Pred LJB2_LRT LJB2_LRT_Pred LJB2_MutationTaster LJB2_MutationTaster_Pred LJB_MutationAssessor LJB_MutationAssessor_Pred LJB2_FATHMM LJB2_GERPPP LJB2_PhyloP LJB2_SiPhy/ ];
         $href->{ljb23_all} = [ qw/LJB23_SIFT_score LJB23_SIFT_score_converted LJB23_SIFT_pred LJB23_Polyphen2_HDIV_score LJB23_Polyphen2_HDIV_pred LJB23_Polyphen2_HVAR_score LJB23_Polyphen2_HVAR_pred LJB23_LRT_score LJB23_LRT_score_converted LJB23_LRT_pred LJB23_MutationTaster_score LJB23_MutationTaster_score_converted LJB23_MutationTaster_pred LJB23_MutationAssessor_score LJB23_MutationAssessor_score_converted LJB23_MutationAssessor_pred LJB23_FATHMM_score LJB23_FATHMM_score_converted LJB23_FATHMM_pred LJB23_RadialSVM_score LJB23_RadialSVM_score_converted LJB23_RadialSVM_pred LJB23_LR_score LJB23_LR_pred LJB23_GERPPP LJB23_PhyloP LJB23_SiPhy/ ];
@@ -327,7 +329,7 @@ has 'annovar_cols' => (
 
 VCF files can be given individually as well.
 
-    #Option is an ArrayRef and can be given as either 
+    #Option is an ArrayRef and can be given as either
 
     --vcfs 1.vcf,2.vcf,3.vcfs
 
@@ -347,13 +349,13 @@ has 'vcfs' => (
 
 
 
-=head3 annotate_vcf 
+=head3 annotate_vcf
 
 Use vcf-annotate from VCF tools to annotate the VCF file
 
 This does not overwrite the original VCF file, but instead creates a new one
 
-To turn this off 
+To turn this off
 
     annovar-wrapper.pl --annotate_vcf 0
 
@@ -367,6 +369,9 @@ has 'annotate_vcf' => (
 );
 
 =head2 Internal Variables
+
+You shouldn't need to change these
+
 =cut
 
 has 'samples' => (
@@ -422,23 +427,24 @@ sub run {
     $self->write_annovar;
 }
 
-=head2 print_opts
+#Moving this over to BioX::Wrapper base class
+#=head2 print_opts
 
-Print out the command line options
+#Print out the command line options
 
-=cut
+#=cut
 
-sub print_opts {
-    my($self) = @_;
+#sub print_opts {
+    #my($self) = @_;
 
-    print "## This file was generated with the options\n";
-    for(my $x=0; $x<=$#ARGV; $x++){
-        next unless $ARGV[$x];
-        print "#\t$ARGV[$x]\t".$ARGV[$x+1]."\n";
-        $x++;
-    }
-    print "\n";
-}
+    #print "## This file was generated with the options\n";
+    #for(my $x=0; $x<=$#ARGV; $x++){
+        #next unless $ARGV[$x];
+        #print "#\t$ARGV[$x]\t".$ARGV[$x+1]."\n";
+        #$x++;
+    #}
+    #print "\n";
+#}
 
 =head2 check_files
 
@@ -451,7 +457,7 @@ sub check_files{
     my($t);
 
     die print "Must specificy an indirectory or vcfs!\n" if (!$self->indir && !$self->vcfs);
-    
+
     if($self->indir){
         $t = $self->indir;
         $t =~ s/\/$//g;
@@ -516,7 +522,7 @@ sub parse_commands{
 
 =head2 write_annovar
 
-Write the commands that 
+Write the commands that
 
 Convert the vcf file to annovar input
 Do the annotations
@@ -533,7 +539,7 @@ sub write_annovar{
     print "## Converting to annovar input\n\n";
     foreach my $file (@{$self->vcfs}){
         print "## Processing file $file\n\n";
-        
+
         $self->file($file);
         my $tname = basename($self->file);
         $tname =~ s/\.vcf$|\.vcf\.gz$//;
@@ -559,7 +565,7 @@ sub write_annovar{
     return unless $self->annotate_vcf;
 
     $self->iter_vcfs('gen_descr');
-    
+
     print "## Wait for file copying bgzip and tabix to finish...\n";
     print "wait\n\n";
 
@@ -573,8 +579,11 @@ sub write_annovar{
 }
 
 =head2 iter_vcfs
+
 Iterate over the vcfs with some changes for lookups
+
 =cut
+
 sub iter_vcfs{
 #    my $self = shift;
     my($self, $fun) = @_;
@@ -616,8 +625,8 @@ sub get_samples{
 
 #    next unless $fh;
 
-    $vcf = Vcf->new(file => $self->file); 
-    $vcf->parse_header(); 
+    $vcf = Vcf->new(file => $self->file);
+    $vcf->parse_header();
     (@samples) = $vcf->get_samples();
 
 #    #TODO Have this in a proper debug msg
@@ -661,6 +670,7 @@ sub convert_annovar{
 =head2 table_annovar
 
 Print out the commands to generate the annotation using table_annovar.pl command.
+
 =cut
 
 sub table_annovar{
@@ -698,14 +708,14 @@ sub vcf_annotate{
 Bgzip, tabix, all of vcftools,  and sort must be in your PATH for these to work.
 
 
-There are two parts to this command. 
+There are two parts to this command.
 
 The first prepares the annotation file.
 
 1. The annotation file is backed up just in case
 2. The annotation file is sorted, because I had some problems with sorting
 3. The annotation file is bgzipped, as required by vcf-annotate
-4. The annotation file is tabix indexed using the special commands -s 1 -b 2 -e 3 
+4. The annotation file is tabix indexed using the special commands -s 1 -b 2 -e 3
 
 The second writes out the vcf-annotate commands
 
@@ -723,7 +733,7 @@ sub gen_descr{
     my($self) = @_;
 
     print "##Prepare to reannotate VCF files\n\n";
-    
+
     make_path($self->outdir."/vcf-annotate_interim") if ! -d $self->outdir."/vcf-annotate_interim";
     make_path($self->outdir."/vcf-annotate_final") if ! -d $self->outdir."/vcf-annotate_final";
 
@@ -740,7 +750,9 @@ sub gen_descr{
 }
 
 =head2 gen_annot
+
 =cut
+
 sub gen_annot {
     my $self = shift;
 
@@ -753,7 +765,7 @@ sub gen_annot {
             print "cat ".$self->file." | ";
         }
         print "vcf-annotate -a ".$self->outdir."/vcf-annotate_interim/".$self->fname.".sorted.annovar.$sample.hg19_multianno.txt.gz \\\n";
-        
+
         foreach my $db (@{$self->annovar_dbs}){
             if(exists $self->annovar_cols->{$db}){
                 my $tmp = $self->annovar_cols->{$db};
@@ -780,8 +792,9 @@ EOF
 
         $self->gen_cols($sample);
     }
-    
+
 }
+
 =head2 gen_cols
 
 Generate the -c portion of the vcf-annotate command
@@ -808,7 +821,7 @@ sub gen_cols{
     }
 
     print $cols." | bgzip -f -c > ".$self->outdir."/vcf-annotate_final/".$self->fname.".$sample.annovar.vcf.gz && \\\n";
-    print "tabix -p vcf ".$self->outdir."/vcf-annotate_final/".$self->fname.".$sample.annovar.vcf.gz\n\n"; 
+    print "tabix -p vcf ".$self->outdir."/vcf-annotate_final/".$self->fname.".$sample.annovar.vcf.gz\n\n";
 
 }
 
@@ -905,13 +918,17 @@ L<http://search.cpan.org/dist/Annovar-Wrapper/>
 
 =head1 ACKNOWLEDGEMENTS
 
-This module is a wrapper around the well developed annovar pipeline. The commands come straight from the documentation.
+This module is a wrapper around the well developed annovar pipeline. The
+commands come straight from the documentation.
 
-This module was originally developed at and for Weill Cornell Medical College in Qatar within ITS Advanced Computing Team and LOTS of input and scientist debugging by Khalid Fahkro. With approval from WCMC-Q, this information was generalized and put on github, for which the authors would like to express their gratitude.
+This module was originally developed at and for Weill Cornell Medical College
+in Qatar within ITS Advanced Computing Team and scientific input from Khalid
+Fahkro. With approval from WCMC-Q, this information was generalized and put on
+github, for which the authors would like to express their gratitude.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014 Jillian Rowe.
+Copyright 2014 Weill Cornell Medical College Qatar.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
