@@ -5,7 +5,7 @@ package Main;
 use Moose;
 #use Carp::Always;
 
-extends 'Annovar::Wrapper';
+extends 'BioX::Wrapper::Annovar';
 
 Main->new_with_options->run;
 
