@@ -27,6 +27,7 @@ fi
 
 find `pwd`/ |grep -e "bam$" | sed 's/bam$//' > bamlist.txt
 
-cat bamlist.txt | xargs -n 1 -I % bash -c "echo 'samtools view -C -T $REF %bam > %cram && samtools index %cram'"
+#Had the order of things WRONG here before
+cat bamlist.txt | xargs -n 1 -I % bash -c "echo 'samtools view -T $REF %bam -C -o %cram && samtools index %cram'"
 
 rm bamlist.txt
